@@ -24,7 +24,7 @@ from ubiquity import misc
 from mythbuntu_common.dictionaries import get_graphics_dictionary
 from mythbuntu_common.installer import *
 from ubiquity import install_misc
-import XKit.xutils
+import xkit.xutils
 import os
 
 NAME = 'myth-drivers'
@@ -131,8 +131,8 @@ class Page(Plugin):
 class Install(InstallPlugin):
 
     def enable_nvidia(self, type, fmt):
-        """Enables an NVIDIA graphics driver using XKit"""
-        xorg_conf=XKit.xutils.XUtils()
+        """Enables an NVIDIA graphics driver using xkit"""
+        xorg_conf=xkit.xutils.XUtils()
 
         extra_conf_options={'NoLogo': '1',
                            'DPI': '100x100'}
@@ -151,62 +151,62 @@ class Install(InstallPlugin):
             extra_conf_options["TVStandard"]=fmt
 
         #Set up extension section
-        extensions = xorg_conf.makeSection('Extensions')
-        xorg_conf.addOption('Extensions', 'Composite', 'Disable', optiontype='Option', position=extensions)
+        extensions = xorg_conf.make_section('Extensions')
+        xorg_conf.add_option('Extensions', 'Composite', 'Disable', option_type='Option', position=extensions)
 
         #Set up device section
         relevant_devices = []
         if len(xorg_conf.globaldict['Device']) == 0:
-            device = xorg_conf.makeSection('Device', identifier='Default Device')
+            device = xorg_conf.make_section('Device', identifier='Default Device')
             relevant_devices.append(device)
-            xorg_conf.setDriver('Device', 'nvidia', device)
+            xorg_conf.set_driver('Device', 'nvidia', device)
         else:
-            devices = xorg_conf.getDevicesInUse()
+            devices = xorg_conf.get_devices_in_use()
             if len(devices) > 0:
                 relevant_devices = devices
             else:
                 relevant_devices = list(xorg_conf.globaldict['Device'].keys())
             for device in relevant_devices:
-                xorg_conf.setDriver('Device', 'nvidia', device)
+                xorg_conf.set_driver('Device', 'nvidia', device)
 
         for device_section in relevant_devices:
             for k, v in extra_conf_options.items():
-                xorg_conf.addOption('Device', k, v, optiontype='Option', position=device_section)
+                xorg_conf.add_option('Device', k, v, option_type='Option', position=device_section)
 
         #Set up screen section
         if len(xorg_conf.globaldict['Screen']) == 0:
-            screen = xorg_conf.makeSection('Screen', identifier='Default Screen')
+            screen = xorg_conf.make_section('Screen', identifier='Default Screen')
 
-        xorg_conf.addOption('Screen', 'DefaultDepth', '24', position=0, prefix='')
+        xorg_conf.add_option('Screen', 'DefaultDepth', '24', position=0, prefix='')
 
-        xorg_conf.writeFile(self.target + "/etc/X11/xorg.conf")
+        xorg_conf.write(self.target + "/etc/X11/xorg.conf")
 
     def enable_amd(self):
-        """Enables an AMD graphics driver using XKit"""
-        xorg_conf=XKit.xutils.XUtils()
+        """Enables an AMD graphics driver using xkit"""
+        xorg_conf=xkit.xutils.XUtils()
 
         #Set up device section
         relevant_devices = []
         if len(xorg_conf.globaldict['Device']) == 0:
-            device = xorg_conf.makeSection('Device', identifier='Default Device')
+            device = xorg_conf.make_section('Device', identifier='Default Device')
             relevant_devices.append(device)
-            xorg_conf.setDriver('Device', 'fglrx', device)
+            xorg_conf.set_driver('Device', 'fglrx', device)
         else:
-            devices = xorg_conf.getDevicesInUse()
+            devices = xorg_conf.get_devices_in_use()
             if len(devices) > 0:
                 relevant_devices = devices
             else:
                 relevant_devices = list(xorg_conf.globaldict['Device'].keys())
             for device in relevant_devices:
-                xorg_conf.setDriver('Device', 'fglrx', device)
+                xorg_conf.set_driver('Device', 'fglrx', device)
 
         #Set up screen section
         if len(xorg_conf.globaldict['Screen']) == 0:
-            screen = xorg_conf.makeSection('Screen', identifier='Default Screen')
+            screen = xorg_conf.make_section('Screen', identifier='Default Screen')
 
-        xorg_conf.addOption('Screen', 'DefaultDepth', '24', position=0, prefix='')
+        xorg_conf.add_option('Screen', 'DefaultDepth', '24', position=0, prefix='')
 
-        xorg_conf.writeFile(self.target + "/etc/X11/xorg.conf")
+        xorg_conf.write(self.target + "/etc/X11/xorg.conf")
 
     def install(self, target, progress, *args, **kwargs):
         progress.info('ubiquity/install/drivers')
