@@ -24,6 +24,7 @@ from mythbuntu_common.installer import MythPageGtk
 from ubiquity import install_misc
 from mythbuntu_common.vnc import VNCHandler
 from ubiquity import misc
+from apt import Cache
 import os
 import subprocess
 import shutil
@@ -97,6 +98,12 @@ class Page(Plugin):
         Plugin.ok_handler(self)
 
 class Install(InstallPlugin):
+    def find_sql(self):
+        cache = Cache()
+        for pkg in cache.keys():
+            if pkg.startswith('mysql-server-core-'):
+                self.sql_version = pkg.split('mysql-server-core-')[1]
+                break
     def process_package_removals(self):
         packages=set()
         ## system role
@@ -107,7 +114,7 @@ class Install(InstallPlugin):
         if 'Slave' in self.type or self.type == 'Frontend':
             packages.add('ntp')              #causes mythtv-backend-master to go
             packages.add('mythtv-database')
-            packages.add('mysql-server-core-5.6')
+            packages.add('mysql-server-core-%s' % self.sql_version )
         if 'Frontend' not in self.type:
             packages.add('mythtv-frontend')
         ## services that are installed by default
@@ -148,7 +155,7 @@ class Install(InstallPlugin):
                 shutil.copytree('/var/lib/mysql','/target/var/lib')
 
             #Setup sql server
-            install_misc.reconfigure(self.target, 'mysql-server-5.6')
+            install_misc.reconfigure(self.target, 'mysql-server-%s' % self.sql_version)
 
             #upstart managed chroot job, 
             #we need stuff working INSIDE the chroot.
@@ -194,6 +201,7 @@ class Install(InstallPlugin):
         self.type = self.progress.get('mythbuntu/install_type')
         self.launched = misc.create_bool(progress.get('mythbuntu/setup-launched'))
 
+        self.find_sql()
         self.setup_common()
         self.setup_roles()
         self.process_package_removals()
