@@ -103,6 +103,7 @@ class Page(Plugin):
 
 class Install(InstallPlugin):
     def install(self, target, progress, *args, **kwargs):
+        import shutil
         user = progress.get('passwd/username')
         type = progress.get('mythbuntu/install_type')
         key  = progress.get('mythtv/mysql_mythtv_user')
@@ -136,43 +137,57 @@ class Install(InstallPlugin):
                  home_dir = pwd.getpwnam("mythbuntu").pw_dir
         except KeyError:
             home_dir = ''
+
         if key.isdigit() and os.path.exists(os.path.join(home_dir,'.mythtv','config.xml')):
-            import shutil
             shutil.copy(os.path.join(home_dir,'.mythtv','config.xml'),
                         os.path.join(home_mythtv_dir,'config.xml'))
 
-        #mythtv.desktop autostart
+        config_dir = target + '/home/' + user + '/.config'
+        desktop_dir = target + '/home/' + user + '/Desktop'
+        autostart_dir =  config_dir + '/autostart'
+
         if 'Backend' in type:
-            desktop_dir = target + '/home/' + user + '/Desktop'
-            setup_link = desktop_dir + '/mythtv-setup.desktop'
+            setup_link = desktop_dir + '/initial-setup.desktop'
             instructions_link = desktop_dir + '/setup-instructions.desktop'
+            autostart_link = autostart_dir + '/initial-setup.desktop'
             if not os.path.isdir(desktop_dir):
                 os.makedirs(desktop_dir)
             if os.path.islink(setup_link) or os.path.exists(setup_link):
                 os.remove(setup_link)
+            shutil.copy(target + '/usr/share/mythbuntu/initial-setup.desktop', setup_link)
+            os.chmod(setup_link, 0o770)
+            shutil.copy(target + '/usr/share/mythbuntu/setup-instructions.desktop', instructions_link)
+            os.chmod(instructions_link, 0o770)
+            #automatically start initial setup on first boot
+            if not os.path.isdir(autostart_dir):
+                os.makedirs(autostart_dir)
+            if os.path.islink(autostart_link) or os.path.exists(autostart_link):
+                os.remove(autostart_link)
             try:
-                os.symlink('/usr/share/applications/mythtv-setup.desktop', setup_link)
+                os.symlink('/usr/share/mythbuntu/initial-setup.desktop', autostart_link)
             except OSError:
-                #on a live disk, this will appear a broken link, but it works
-                pass
-            try:
-                os.symlink('/usr/share/mythbuntu/setup-instructions.desktop', instructions_link)
-            except OSError:
-                #on a live disk, this will appear a broken link, but it works
                 pass
             
         if 'Frontend' in type:
-            desktop_dir = target + '/home/' + user + '/Desktop'
             desktop_link = desktop_dir + '/mythtv.desktop'
             if not os.path.isdir(desktop_dir):
                 os.makedirs(desktop_dir)
             if os.path.islink(desktop_link) or os.path.exists(desktop_link):
                 os.remove(desktop_link)
-            try:
-                os.symlink('/usr/share/applications/mythtv.desktop', desktop_link)
-            except OSError:
-                #on a live disk, this will appear a broken link, but it works
-                pass
+            shutil.copy(target + '/usr/share/applications/mythtv.desktop', desktop_link)
+            os.chmod(desktop_link, 0o770)
+            #if not backend installed then start frontend on first boot
+            if 'Backend' not in type:
+                autostart_link = autostart_dir + '/mythtv.desktop'
+                if not os.path.isdir(autostart_dir):
+                    os.makedirs(autostart_dir)
+                if os.path.islink(autostart_link) or os.path.exists(autostart_link):
+                    os.remove(autostart_link)
+                try:
+                    os.symlink('/usr/share/applications/mythtv.desktop',autostart_link)
+                except OSError:
+                    pass
+
 
         #prep user for stuff we did
         install_misc.chrex(target, 'adduser', user, 'mythtv')
