@@ -131,7 +131,7 @@ class Install(InstallPlugin):
             f=open(target + '/etc/mysql/conf.d/mythtv.cnf','w')
             print("""\
 [mysqld]
-bind-address=0.0.0.0""", file=f)
+bind-address=::""", file=f)
             f.close()
 
         #Mark new items
